# watchmaker

Applied Configuration Management

--------------

## Overview

Watchmaker helps provision a system from its initial installation to its final
configuration. It was inspired by a desire to eliminate static system images
with embedded configuration settings (e.g. gold disks) and the pain associated
with maintaining them.

## Contents

*   [Installation](installation.md)
*   [Configuration](configuration.md)
*   [Usage](usage.md)
*   [Frequently Asked Questions](faq.md)
*   [API Reference](api.md)
*   [Contributing](contributing.rst)
